<?php

namespace Drp\ProjectHelpers\Tests;

use Exception;

/**
 * Class Handler
 * @package Drp\ProjectHelpers
 */
class Handler extends \Illuminate\Foundation\Exceptions\Handler
{
    /**
     * @var bool
     */
    protected $disabled;

    /**
     * A list of the exception types that should not be reported.
     *
     * @var array
     */
    protected $dontReport = [
        \Illuminate\Auth\AuthenticationException::class,
        \Illuminate\Auth\Access\AuthorizationException::class,
        \Symfony\Component\HttpKernel\Exception\HttpException::class,
        \Illuminate\Database\Eloquent\ModelNotFoundException::class,
        \Illuminate\Session\TokenMismatchException::class,
        \Illuminate\Validation\ValidationException::class,
    ];

    /**
     * Handler constructor.
     * @param bool $disabled
     */
    public function __construct($disabled = false)
    {
        return $this->disabled = $disabled;
    }

    /**
     * Render an exception into an HTTP response.
     *
     * @param  \Illuminate\Http\Request $request
     * @param  \Exception $exception
     * @return \Illuminate\Http\Response
     */
    public function render($request, Exception $exception)
    {
        if ($this->disabled) {
            throw $exception;
        }

        return parent::render($request, $exception);
    }

    /**
     * Report or log an exception.
     * This is a great spot to send exceptions to Sentry, Bugsnag, etc.
     *
     * @param  \Exception $exception
     * @return void
     */
    public function report(Exception $exception)
    {
        if ($this->disabled) {
            throw $exception;
        }

        parent::report($exception);
    }
}
