<?php

namespace Drp\ProjectHelpers\Test;

use Drp\ProjectHelpers\Tests\Concerns\HasFakeHasher;
use Drp\ProjectHelpers\Tests\Helpers\Hasher;
use Illuminate\Hashing\BcryptHasher;

/**
 * Class HasherTest
 * @package Drp\ProjectHelpers\Test
 */
class HasherTest extends TestCase
{
    use HasFakeHasher;

    /**
     * @test
     */
    public function hasher_does_not_actually_hash()
    {
        $hasher = new Hasher;
        $value = $hasher->make('password');
        $this->assertSame('password', $value);
        $this->assertTrue($hasher->check('password', $value));
        $this->assertFalse($hasher->needsRehash($value));
        $this->assertFalse($hasher->needsRehash($value, ['rounds' => 1]));
    }

    /**
     * @test
     */
    public function can_use_fake_hasher_with_hasher_factory()
    {
        $this->userFakeHasher();

        $this->assertTrue(app('hash')->check('password', 'password'));
    }

    /**
     * @test
     */
    public function can_use_fake_hasher_with_bcrypt_hasher()
    {
        //Set the hash to be an instance of a hasher (Laravel <5.5)
        app()->alias(BcryptHasher::class, 'hash');

        $this->userFakeHasher();

        $this->assertTrue(app('hash')->check('password', 'password'));
    }
}